searchData={"items":[{"type":"module","title":"Lift","doc":"The `Lift` lib provides functions for working with multi-level nested lists.\nIt offers a clean, intuitive interface to transform or access data at specific\nlevels of nesting while preserving the overall structure of the data.\n\nThis module is particularly useful when you need to:\n  * Map functions over deeply nested lists at a specific level\n  * Transform data within nested structures without flattening\n  * Handle complex nested data structures while maintaining their shape","ref":"Lift.html"},{"type":"module","title":"Core Functions - Lift","doc":"* `l2map/2` - Maps a function over 2-level nested lists\n  * `l3map/2` - Maps a function over 3-level nested lists\n  * `l4map/2` - Maps a function over 4-level nested lists\n  * `l5map/2` - Maps a function over 5-level nested lists\n  * `lmap/3` - The general version which maps a function over elements at any specified nesting level","ref":"Lift.html#module-core-functions"},{"type":"module","title":"Examples - Lift","doc":"A simple transformation at the second level:\n\n      iex> numbers = [[1, 2], [3, 4]]\n      iex> Lift.l2map(numbers, fn x -> x * 2 end)\n      [[2, 4], [6, 8]]","ref":"Lift.html#module-examples"},{"type":"module","title":"Name Origin - Lift","doc":"The name \"Lift\" comes from functional programming concepts, specifically the idea of\n  \"lifting\" when work with functors. In functional programming, when we compose\n  functors (like nested lists), we \"lift\" our function to work at different levels of\n  the structure. This is similar to Haskell's `fmap . fmap` composition, which lifts\n  a function to work with nested functors.","ref":"Lift.html#module-name-origin"},{"type":"function","title":"Lift.l2map/2","doc":"Maps a function over a 2-level nested list.\nTakes a nested list as the first argument, followed by a mapping function.\nThis is equivalent to calling `lmap(list, 2, fun)`.","ref":"Lift.html#l2map/2"},{"type":"function","title":"Examples - Lift.l2map/2","doc":"iex> numbers = [[1, 2], [3, 4], [5, 6]]\n   iex> Lift.l2map(numbers, fn x -> x * 2 end)\n   [[2, 4], [6, 8], [10, 12]]\n\n   iex> strings = [[\"a\", \"b\"], [\"c\", \"d\"]]\n   iex> Lift.l2map(strings, &String.upcase/1)\n   [[\"A\", \"B\"], [\"C\", \"D\"]]","ref":"Lift.html#l2map/2-examples"},{"type":"function","title":"Lift.l3map/2","doc":"Maps a function over a 3-level nested list.\nTakes a nested list as the first argument, followed by a mapping function.\nThis is equivalent to calling `lmap(list, 3, fun)`.","ref":"Lift.html#l3map/2"},{"type":"function","title":"Examples - Lift.l3map/2","doc":"iex> numbers = [[[1, 2], [3, 4]], [[5, 6], [7, 8]]]\n   iex> Lift.l3map(numbers, fn x -> x + 1 end)\n   [[[2, 3], [4, 5]], [[6, 7], [8, 9]]]\n\n   iex> strings = [[[\"hello\", \"world\"], [\"foo\"]], [[\"bar\"], [\"baz\", \"qux\"]]]\n   iex> Lift.l3map(strings, &String.capitalize/1)\n   [[[\"Hello\", \"World\"], [\"Foo\"]], [[\"Bar\"], [\"Baz\", \"Qux\"]]]","ref":"Lift.html#l3map/2-examples"},{"type":"function","title":"Lift.l4map/2","doc":"Maps a function over a 4-level nested list.\nTakes a nested list as the first argument, followed by a mapping function.\nThis is equivalent to calling `lmap(list, 4, fun)`.","ref":"Lift.html#l4map/2"},{"type":"function","title":"Examples - Lift.l4map/2","doc":"iex> numbers = [[[[1, 2], [3]], [[4, 5]]], [[[6]], [[7, 8], [9]]]]\n   iex> Lift.l4map(numbers, fn x -> x * 2 end)\n   [[[[2, 4], [6]], [[8, 10]]], [[[12]], [[14, 16], [18]]]]\n\n   iex> strings = [[[[{\"a\", 1}]]], [[[{\"b\", 2}]]]]\n   iex> Lift.l4map(strings, fn {str, num} -> {String.upcase(str), num} end)\n   [[[[{\"A\", 1}]]], [[[{\"B\", 2}]]]]","ref":"Lift.html#l4map/2-examples"},{"type":"function","title":"Lift.l5map/2","doc":"Maps a function over a 5-level nested list.\nTakes a nested list as the first argument, followed by a mapping function.\nThis is equivalent to calling `lmap(list, 5, fun)`.","ref":"Lift.html#l5map/2"},{"type":"function","title":"Examples - Lift.l5map/2","doc":"iex> numbers = [[[[[1]], [[2]]], [[[3]]]], [[[[4]]], [[[5]], [[6]]]]]\n   iex> Lift.l5map(numbers, fn x -> x + 10 end)\n   [[[[[11]], [[12]]], [[[13]]]], [[[[14]]], [[[15]], [[16]]]]]\n\n   iex> data = [[[[[%{x: 1}]], [[%{x: 2}]]]], [[[[%{x: 3}]]]]]\n   iex> Lift.l5map(data, fn map -> Map.update!(map, :x, & &1 * 2) end)\n   [[[[[%{x: 2}]], [[%{x: 4}]]]], [[[[%{x: 6}]]]]]","ref":"Lift.html#l5map/2-examples"},{"type":"function","title":"Lift.lmap/3","doc":"Maps a function over a nested list at the specified level of nesting.\nTakes a nested list as the first argument, followed by the nesting level\nand a mapping function.","ref":"Lift.html#lmap/3"},{"type":"function","title":"Parameters - Lift.lmap/3","doc":"* `list` - A nested list to transform\n  * `level` - The level of nesting at which to apply the function\n  * `fun` - The function to apply at the specified nesting level","ref":"Lift.html#lmap/3-parameters"},{"type":"function","title":"Examples - Lift.lmap/3","doc":"iex> Lift.lmap([[1, 2], [3, 4], [5, 6]], 2, fn i -> i * 10 end)\n    [[10, 20], [30, 40], [50, 60]]\n\n    iex> Lift.lmap([[[\"a\", \"b\"], [\"c\", \"d\"]], [[\"e\", \"f\"], [\"g\", \"h\"]], [[\"i\", \"j\"], [\"k\", \"l\"]]], 3, &String.upcase/1)\n    [[[\"A\", \"B\"], [\"C\", \"D\"]], [[\"E\", \"F\"], [\"G\", \"H\"]], [[\"I\", \"J\"], [\"K\", \"L\"]]]","ref":"Lift.html#lmap/3-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}